![Redivis Logo](https://github.com/redivis/redivis-python/raw/main/assets/logo_small.png)
# redivis-python
[Redivis](https://redivis.com) client library for python! 

Connect data on Redivis to the Python scientific stack, and script your data management tasks.

## Beta disclaimer
This library is currently in beta testing. Many of the interfaces are nearing stability, but there may still be backwards-incompatible changes in the future. 

Please report any issues or feature requests in the [issue tracker](https://github.com/redivis/redivis-python/issues).

## Documentation
Comprehensive documentation for this package is available at https://apidocs.redivis.com/client-libraries/redivis-python

## Contributing
Please report any issues or feature requests in the [issue tracker](https://github.com/redivis/redivis-python/issues)
 — your feedback is much appreciated!
